add_topo_sort: Add topo_sort

View source: R/sort_network.R

add_topo_sortR Documentation

Add topo_sort

Description

calls sort_network without support for splitting the network and adds a nrow:1 topo_sort attribute.

Usage

add_topo_sort(x, outlets = NULL)

## S3 method for class 'data.frame'
add_topo_sort(x, outlets = NULL)

## S3 method for class 'hy'
add_topo_sort(x, outlets = NULL)

## S3 method for class 'hy_node'
add_topo_sort(x, outlets = NULL)

## S3 method for class 'hy_flownetwork'
add_topo_sort(x, outlets = NULL)

## S3 method for class 'hy_topo'
add_topo_sort(x, outlets = NULL)

Arguments

x

data.frame network compatible with hydroloom_names.

outlets

same as id in x. if specified, only the network emanating from these outlets will be considered and returned.

Details

Required attributes: id, toid

Value

data.frame containing a topo_sort attribute.


hydroloom documentation built on Aug. 4, 2026, 1:07 a.m.