| get_bridge_flowlines | R Documentation |
Identifies bridge flowlines (cut edges) in the network. Bridge flowlines are those whose removal would disconnect the network. Flowlines are edges in the underlying node graph, so bridge detection correctly identifies the sole-path flowlines that separate parts of the network – including flowlines within diversion systems that do not rejoin.
get_bridge_flowlines(x, quiet = FALSE)
## S3 method for class 'data.frame'
get_bridge_flowlines(x, quiet = FALSE)
## S3 method for class 'hy'
get_bridge_flowlines(x, quiet = FALSE)
## S3 method for class 'hy_node'
get_bridge_flowlines(x, quiet = FALSE)
## S3 method for class 'hy_flownetwork'
get_bridge_flowlines(x, quiet = FALSE)
## S3 method for class 'hy_topo'
get_bridge_flowlines(x, quiet = FALSE)
x |
data.frame network compatible with hydroloom_names. |
quiet |
logical quiet messages? |
Required attributes: id, toid
vector of flowline ids that are bridge flowlines in the network
x <- data.frame(
id = c(1, 2, 3, 4, 5, 6, 7, 8, 9),
toid = c(2, 3, 4, 5, 0, 7, 8, 9, 4)
)
# 1 -> 2 -> 3 -> 4 -> 5
# ^
# |
# 6 -> 7 -> 8 -> 9
#
# Dendritic tree: all flowlines are bridges
get_bridge_flowlines(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.