format_index_ids is deprecated and will be removed in a future release.
Arguments
- g
data.frame graph with
id,inidandtoindidas returned by make_index_ids- return_list
logical if TRUE, the returned list will include a "froms_list" element containing all from ids in a list form.