make_fromids is deprecated and will be removed in a future release.
Use make_index_ids with mode = "from" instead.
Arguments
- index_ids
data.frame as returned by make_index_ids
- return_list
logical if TRUE, the returned list will include a "froms_list" element containing all from ids in a list form.
- upmain
data.frame containing
idandupmaincolumns.upmainshould be a logical value indicating if the id is the upmain connection from its downstream neighbors.