View source: R/make_index_ids.R
| make_fromids | R Documentation |
make_fromids is deprecated and will be removed in a future release.
Use make_index_ids with mode = "from" instead.
make_fromids(index_ids, return_list = FALSE, upmain = NULL)
index_ids |
data.frame as returned by make_index_ids |
return_list |
logical if TRUE, the returned list will include a "froms_list" element containing all from ids in a list form. |
upmain |
data.frame containing |
list containing a "froms" matrix, "lengths" vector, and optionally "froms_list" elements.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.